import time
import traceback

import requests
from fake_useragent import UserAgent
import re
import sys
from .delay_wrapper import delayed

sys.setrecursionlimit(100000)


class geturl:
    def __init__(self):
        self.header = {
            'user-agent': str(UserAgent().random)
        }
        self.url_list = []
        self.err_url = []
        self.start_time = int(time.time())

    @delayed(0)
    def request(self, url, domain, timeout, count, is_external=0):
        try:
            res = requests.get(url, headers=self.header, timeout=3)
            res.encoding = res.apparent_encoding
            html = res.text
            self.all_url(html, domain, timeout, count, is_external)
        except:
            self.err_url.append(url)

    def all_url(self, resp, domain, timeout, count, is_external=0):
        all_url = re.findall('href="(.+?)"', resp) + re.findall('src="(.+?)"', resp)\
                  + re.findall('target="(.+?)"', resp)
        for link in all_url:
            if is_external == 0:
                if (link.startswith('http')) and (link not in self.url_list) and (domain in link) and \
                        (len(self.url_list) < int(count)) and ((int(time.time()) - self.start_time) < int(timeout)):
                    self.url_list.append(link)
                    print(link)
                    f = open('url.txt', 'a+', encoding='utf-8')
                    f.write(str(link) + '\n')
                    f.close()
                    print(link)
                    self.request(link, domain,  timeout, count, is_external)
            else:
                if (link.startswith('http')) and (link not in self.url_list) and \
                        (len(self.url_list) < int(count)) and ((int(time.time()) - self.start_time) < int(timeout)):
                    self.url_list.append(link)
                    f = open('url.txt', 'a+', encoding='utf-8')
                    f.write(str(link) + '\n')
                    f.close()
                    print(link)
                    self.request(link, domain,  timeout, count, is_external)


    def startres(self, url, domain, timeout, count, is_external=0):
        self.request(url, domain, timeout, count, is_external)
        return self.url_list


if __name__ == '__main__':
    allurl = geturl()
    url_list = allurl.startres('https://blog.csdn.net', 'csdn.net', 300, 300, is_external=0)


# 异步下载视频
from threading import Timer


def delayed(seconds):
    def decorator(func):
        def wrapper(*args, **kwargs):
            a_timer = Timer(seconds, func, args=args, kwargs=kwargs)
            a_timer.start()

        return wrapper

    return decorator



from distutils.core import setup
setup(
  name = 'weballurl',         # How you named your package folder (MyLib)
  packages = ['weballurl'],   # Chose the same as "name"
  version = '1.1.7',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = '获取一个指定网站所有的本站url；Gets all site urls for a specified site',   # Give a short description about your library
  author = 'zyg0531',                   # Type in your name
  author_email = '1455857826@qq.com',      # Type in your E-Mail
  url = 'https://github.com/zhangyg531/weballurl',   # Provide either the link to your github or to your website
  download_url = 'https://codeload.github.com/zhangyg531/weballurl/zip/refs/heads/main',    # I explain this later on
  keywords = ['url', 'allurl', 'wenallurl'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'requests',       # 可以加上版本号，如validators=1.5.1
          'fake_useragent',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.8',
  ],
)